@@ -1,33 +1,10 @@
-# Copyright (C) 2009-2014 by Barry A. Warsaw
-#
-# This file is part of flufl.i18n
-#
-# flufl.i18n is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, version 3 of the License.
-#
-# flufl.i18n is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
-# for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with flufl.i18n.  If not, see <http://www.gnu.org/licenses/>.
-
 """An application."""
 
-from __future__ import absolute_import, print_function, unicode_literals
-
-__metaclass__ = type
-__all__ = [
-    'Application',
-    ]
-
-
 from flufl.i18n._translator import Translator
+from gettext import NullTranslations
+from public import public
 
 
-
 class _Using:
     """Context manager for _.using()."""
 
@@ -44,7 +21,21 @@ class _Using:
         return False
 
 
-
+class _Defer:
+    """Context manager for _.defer_translation()."""
+
+    def __init__(self, application):
+        self._application = application
+
+    def __enter__(self):
+        self._application.defer()
+
+    def __exit__(self, *exc_info):
+        self._application.pop()
+        # Do not suppress exceptions.
+        return False
+
+
 class _Underscore:
     """The implementation of the _() function.
 
@@ -76,6 +67,15 @@ class _Underscore:
         """
         return _Using(self._application, language_code)
 
+    def defer_translation(self):
+        """Push a NullTranslations onto the stack.
+
+        This is useful for when you want to mark strings statically for
+        extraction but you want to defer translation of the string until
+        later.
+        """
+        return _Defer(self._application)
+
     def push(self, language_code):
         """Push a new catalog onto the stack.
 
@@ -125,7 +125,7 @@ class _Underscore:
         return code
 
 
-
+@public
 class Application:
     """Manage all the catalogs for a particular application.
 
@@ -226,6 +226,15 @@ class Application:
         """
         return _Underscore(self)
 
+    def defer(self):
+        """Push a deferred (i.e. null) translation context onto the stack.
+
+        This is primarily used to support the ``_.defer_translation()``
+        context manager.
+        """
+        self._stack.append(
+            ('', Translator(NullTranslations(), self.dedent, self.depth)))
+
     def push(self, language_code):
         """Push a new catalog onto the stack.
 
